---

slug: /literal-overview
---

# Literals

A literal is a fixed value.

Many functions and SQL statements require you to specify a literal. A literal can also be part of an expression or a condition.

seekdb supports the following literals:

* [String literals](../400.literal/200.string-literal.md)

* [Numeric literals](../400.literal/300.numeric-value.md)

* [Date and time literals](../400.literal/400.date-and-time.md)

* [Bit literals](../400.literal/500.hexadecimal-numeric.md)

* [Boolean literals](../400.literal/600.boolean.md)

* [NULL literals](../400.literal/700.null-value.md)